@@ -24,7 +24,7 @@ import sunpy.coordinates
 import sunpy.data.test
 import sunpy.map
 import sunpy.sun
-from sunpy.coordinates import sun
+from sunpy.coordinates import HeliographicCarrington, HeliographicStonyhurst, sun
 from sunpy.map.sources import AIAMap
 from sunpy.time import parse_time
 from sunpy.util import SunpyDeprecationWarning, SunpyUserWarning
@@ -825,6 +825,13 @@ def test_rotate_with_incompatible_missing_dtype():
         test_map.rotate(order=3, missing=np.nan)
 
 
+def test_rotate_crpix_zero_degrees(generic_map):
+    # Rotating a map by zero degrees should not change the location of the reference pixel at all
+    rotated_map = generic_map.rotate(0*u.deg)
+    assert rotated_map.reference_pixel.x == generic_map.reference_pixel.x
+    assert rotated_map.reference_pixel.y == generic_map.reference_pixel.y
+
+
 def test_rotate_pad_crpix(generic_map):
     rotated_map = generic_map.rotate(30*u.deg)
     # This tests that the reference pixel of the map is in the expected place.
@@ -871,6 +878,46 @@ def test_rotate_invalid_order(generic_map):
         generic_map.rotate(order=-1)
 
 
+def test_rotate_assumed_obstime():
+    # Create an HPC map that is missing the observing time and has an off-disk reference coordinate
+    header = {
+        'crval1': -2000,
+        'crval2': 0,
+        'cdelt1': 1,
+        'cdelt2': 1,
+        'ctype1': 'HPLN-TAN',
+        'ctype2': 'HPLT-TAN',
+        'naxis': 2,
+        'naxis1': 10,
+        'naxis2': 10,
+        'cunit1': 'arcsec',
+        'cunit2': 'arcsec',
+        'crpix1': 4.5,
+        'crpix2': 6.5,
+        'hglt_obs': 0,
+        'hgln_obs': 0,
+        'dsun_obs': 150000000000,
+        'rsun_ref': 700000000,
+    }
+    original = sunpy.map.Map(np.zeros((10, 10)), header)
+
+    # Accessing the date makes the assumption of "now" for obstime
+    with pytest.warns(SunpyUserWarning, match="Missing metadata for observation time"):
+        original.date
+
+    # The assumption has already been made, so no further warning should be emitted by rotate()
+    rotated = original.rotate(0*u.deg)
+
+    # The reference coordinate should be unchanged by this 0-degree rotation
+    # Since the reference coordinate is off-disk, a non-identity transformation would result in NaNs
+    assert_quantity_allclose(rotated.reference_pixel.x, original.reference_pixel.x)
+    assert_quantity_allclose(rotated.reference_pixel.y, original.reference_pixel.y)
+
+    # The returned map should also be missing observing time
+    with pytest.warns(SunpyUserWarning, match="Missing metadata for observation time"):
+        rotated.date
+
+
 def test_as_mpl_axes_aia171(aia171_test_map):
     ax = plt.subplot(projection=aia171_test_map)
     assert isinstance(ax, wcsaxes.WCSAxes)
@@ -1256,3 +1303,45 @@ def test_meta_modifications(aia171_test_map):
     assert set(aiamap_rot.meta.added_items.keys()) == set(['bunit', 'pc1_1', 'pc1_2', 'pc2_1', 'pc2_2'])
     assert set(aiamap_rot.meta.removed_items.keys()) == set(['crota2'])
     assert set(aiamap_rot.meta.modified_items) == set(['cdelt1', 'crpix1', 'crpix2', 'crval1'])
+
+
+def test_no_wcs_observer_info(heliographic_test_map):
+    # Check that HeliographicCarrington WCS has observer info set
+    assert isinstance(heliographic_test_map.coordinate_frame, HeliographicCarrington)
+    wcs_aux = heliographic_test_map.wcs.wcs.aux
+    assert wcs_aux.hgln_obs is not None
+    assert wcs_aux.hglt_obs is not None
+    assert wcs_aux.dsun_obs is not None
+
+    # Remove observer information, and change coordinate system to HeliographicStonyhurst
+    heliographic_test_map.meta.pop('HGLN_OBS')
+    heliographic_test_map.meta.pop('HGLT_OBS')
+    heliographic_test_map.meta.pop('DSUN_OBS')
+    heliographic_test_map.meta['CTYPE1'] = 'HGLN-CAR'
+    heliographic_test_map.meta['CTYPE2'] = 'HGLT-CAR'
+    assert isinstance(heliographic_test_map.coordinate_frame, HeliographicStonyhurst)
+
+    # Check that GenericMap.wcs doesn't set an observer
+    wcs_aux = heliographic_test_map.wcs.wcs.aux
+    assert wcs_aux.hgln_obs is None
+    assert wcs_aux.hglt_obs is None
+    assert wcs_aux.dsun_obs is None
+
+
+def test_rsun_meters_no_warning_for_hgs(heliographic_test_map):
+    # Make sure that Stonyhurst heliographic maps do not emit a warning about assuming an
+    # Earth-based observer when returning the physical radius of the Sun, because such an
+    # assumption is not necessary
+
+    # Convert the heliographic test map to Stonyhurst heliographic coordinates
+    heliographic_test_map.meta.pop('HGLN_OBS')
+    heliographic_test_map.meta.pop('HGLT_OBS')
+    heliographic_test_map.meta.pop('DSUN_OBS')
+    heliographic_test_map.meta['CTYPE1'] = 'HGLN-CAR'
+    heliographic_test_map.meta['CTYPE2'] = 'HGLT-CAR'
+
+    # Add a custom physical radius for the Sun
+    heliographic_test_map.meta['rsun_ref'] = 1.1 * sunpy.sun.constants.radius.to_value(u.m)
+
+    assert_quantity_allclose(heliographic_test_map.rsun_meters,
+                             heliographic_test_map.meta['rsun_ref'] << u.m)
